pub struct ChildBackoffFn(pub Arc<dyn Fn(&str, usize, Instant, Option<Duration>) -> Option<Duration> + Send + Sync>);Expand description
A function pointer for computing child-level backoff delays before re-spawning a child.
This function is invoked each time a child fails:
ⓘ
(child_id, current_restart_count, last_fail_instant, reset_after)
-> Option<Duration>If you return Some(duration), the supervisor will wait that amount of time before actually re-spawning the child.
If None, it restarts immediately.
Tuple Fields
0: Arc<dyn Fn(&str, usize, Instant, Option<Duration>) -> Option<Duration> + Send + Sync>Implementations
Sourceimpl ChildBackoffFn
impl ChildBackoffFn